@@ -153,7 +153,7 @@ def cola():
 
 
 def commit():
-    return icon('git-commit.svg')
+    return icon('document-save-symbolic.svg')
 
 
 def compare():
@@ -232,6 +232,10 @@ def merge():
     return icon('git-merge.svg')
 
 
+def modified():
+    return icon('modified.svg')
+
+
 def modified_name():
     return name_from_basename('modified.svg')
 
