@@ -96,6 +96,7 @@ class GitRepoModel(QtGui.QStandardItemModel):
                                            item_type=GitRepoNameItem.TYPE)
         return qtutils.mimedata_from_paths(context, paths)
 
+    # pylint: disable=no-self-use
     def mimeTypes(self):
         return qtutils.path_mimetypes()
 
@@ -123,23 +124,13 @@ class GitRepoModel(QtGui.QStandardItemModel):
             row = self.entries[path]
         except KeyError:
             if create:
-                column = self.create_column
+                column = create_column
                 row = self.entries[path] = [
                     column(c, path, is_dir) for c in Columns.ALL]
             else:
                 row = None
         return row
 
-    def create_column(self, col, path, is_dir):
-        """Creates a StandardItem for use in a treeview cell."""
-        # GitRepoNameItem is the only one that returns a custom type()
-        # and is used to infer selections.
-        if col == Columns.NAME:
-            item = GitRepoNameItem(path, is_dir)
-        else:
-            item = GitRepoItem(path)
-        return item
-
     def populate(self, item):
         self.populate_dir(item, item.path + '/')
 
@@ -261,6 +252,17 @@ class GitRepoModel(QtGui.QStandardItemModel):
         self._runtask.start(task)
 
 
+def create_column(col, path, is_dir):
+    """Creates a StandardItem for use in a treeview cell."""
+    # GitRepoNameItem is the only one that returns a custom type()
+    # and is used to infer selections.
+    if col == Columns.NAME:
+        item = GitRepoNameItem(path, is_dir)
+    else:
+        item = GitRepoItem(path)
+    return item
+
+
 class GitRepoInfoTask(qtutils.Task):
     """Handles expensive git lookups for a path."""
 
@@ -414,7 +416,7 @@ class GitRepoNameItem(GitRepoItem):
         which paths are selected.
 
         """
-        return GitRepoNameItem.TYPE
+        return self.TYPE
 
     def hasChildren(self):
         return self.is_dir
